.. networking-bagpipe documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

networking-bagpipe's documentation
==================================

.. include:: ../../README.rst

Documentation
=============

.. toctree::
   :maxdepth: 2

   design
   applications
   bagpipe-bgp
   installation
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
